@@ -20,6 +20,7 @@
 #include <mlpack/bindings/python/default_param.hpp>
 #include <mlpack/bindings/julia/default_param.hpp>
 #include <mlpack/bindings/go/default_param.hpp>
+#include <mlpack/bindings/R/default_param.hpp>
 
 namespace mlpack {
 namespace bindings {
@@ -30,29 +31,34 @@ namespace markdown {
  * printed depends on the current setting of BindingInfo::Language().
  */
 template<typename T>
-void DefaultParam(const util::ParamData& data,
+void DefaultParam(util::ParamData& data,
                   const void* /* input */,
                   void* output)
 {
   if (BindingInfo::Language() == "cli")
   {
     *((std::string*) output) =
-        cli::DefaultParamImpl<typename std::remove_pointer<T>::type>(data);
+        cli::DefaultParamImpl<std::remove_pointer_t<T>>(data);
   }
   else if (BindingInfo::Language() == "python")
   {
     *((std::string*) output) =
-        python::DefaultParamImpl<typename std::remove_pointer<T>::type>(data);
+        python::DefaultParamImpl<std::remove_pointer_t<T>>(data);
   }
   else if (BindingInfo::Language() == "julia")
   {
     *((std::string*) output) =
-        julia::DefaultParamImpl<typename std::remove_pointer<T>::type>(data);
+        julia::DefaultParamImpl<std::remove_pointer_t<T>>(data);
   }
   else if (BindingInfo::Language() == "go")
   {
     *((std::string*) output) =
-        go::DefaultParamImpl<typename std::remove_pointer<T>::type>(data);
+        go::DefaultParamImpl<std::remove_pointer_t<T>>(data);
+  }
+  else if (BindingInfo::Language() == "r")
+  {
+    *((std::string*) output) =
+        r::DefaultParamImpl<std::remove_pointer_t<T>>(data);
   }
   else
   {
