@@ -156,7 +156,7 @@ std::string PrintInputOptions(util::Params& params,
 
     bool isHyperParam = false;
     size_t foundArma = d.cppType.find("arma");
-    if(d.input && foundArma == std::string::npos &&
+    if (d.input && foundArma == std::string::npos &&
         !isSerial)
       isHyperParam = true;
 
@@ -164,9 +164,12 @@ std::string PrintInputOptions(util::Params& params,
 
     // no parameter is both a hyper-parameter and a matrix-parmeter
     // hence the print condition is "false".
-    if(onlyHyperParams && onlyMatrixParams) printCondition = false;
-    else if(onlyHyperParams) printCondition = isHyperParam;
-    else if(onlyMatrixParams) printCondition = foundArma != std::string::npos;
+    if (onlyHyperParams && onlyMatrixParams)
+      printCondition = false;
+    else if (onlyHyperParams)
+      printCondition = isHyperParam;
+    else if (onlyMatrixParams)
+      printCondition = foundArma != std::string::npos;
 
     if (printCondition)
     {
@@ -180,9 +183,9 @@ std::string PrintInputOptions(util::Params& params,
   else
   {
     // Unknown parameter!
-    throw std::runtime_error("Unknown parameter '" + GetValidName(paramName) + "' " +
-        "encountered while assembling documentation!  Check BINDING_LONG_DESC()"
-        + " and BINDING_EXAMPLE() declaration.");
+    throw std::runtime_error("Unknown parameter '" + GetValidName(paramName) +
+        "' encountered while assembling documentation!  "
+        "Check BINDING_LONG_DESC() and BINDING_EXAMPLE() declaration.");
   }
 
   // Continue recursion.
@@ -414,7 +417,8 @@ inline std::string SplitTrainTest(const std::string& datasetName,
                                   const std::string& splitRatio)
 {
   std::string splitString;
-  splitString += ">>> d = preprocess_split(input_=" + datasetName + ", input_labels=";
+  splitString += ">>> d = preprocess_split(input_=" + datasetName +
+      ", input_labels=";
   splitString += labelName + ", test_ratio=" + splitRatio + ")\n";
   splitString += ">>> " + trainDataset + " = d['training']\n";
   splitString += ">>> " + trainLabels + " = d['training_labels']\n";
@@ -464,12 +468,12 @@ inline std::string CreateObject(const std::string& bindingName,
 
     bool isHyperParam = false;
     size_t foundArma = it->second.cppType.find("arma");
-    if(it->second.input && foundArma == std::string::npos &&
-        !isSerial)
+    if (it->second.input && foundArma == std::string::npos && !isSerial)
       isHyperParam = true;
 
-    if(!isHyperParam) continue;
-    if(it->second.name == "help" || it->second.name == "info" ||
+    if (!isHyperParam)
+      continue;
+    if (it->second.name == "help" || it->second.name == "info" ||
         it->second.name == "version")
         continue;
 
@@ -501,9 +505,10 @@ std::string CallMethod(const std::string& bindingName,
   std::string callMethod = ">>> ";
 
   // find out if there are any output options.
-  for(auto it=parameters.begin(); it!=parameters.end(); it++)
+  for (auto it = parameters.begin(); it != parameters.end(); it++)
   {
-    if(it->second.input) continue;
+    if (it->second.input)
+      continue;
     callMethod += it->first + ", ";
   }
   if (callMethod != "")
