@@ -1,5 +1,5 @@
 /**
- * @file dataset_mapper.hpp
+ * @file core/data/dataset_mapper.hpp
  * @author Ryan Curtin
  * @author Keon Kim
  *
@@ -151,10 +151,10 @@ class DatasetMapper
    * Serialize the dataset information.
    */
   template<typename Archive>
-  void serialize(Archive& ar, const unsigned int /* version */)
+  void serialize(Archive& ar, const uint32_t /* version */)
   {
-    ar & BOOST_SERIALIZATION_NVP(types);
-    ar & BOOST_SERIALIZATION_NVP(maps);
+    ar(CEREAL_NVP(types));
+    ar(CEREAL_NVP(maps));
   }
 
   //! Return the policy of the mapper.
@@ -170,8 +170,8 @@ class DatasetMapper
   std::vector<Datatype> types;
 
   // Forward mapping type.
-  using ForwardMapType = typename std::unordered_map<InputType, typename
-      PolicyType::MappedType>;
+  using ForwardMapType = std::unordered_map<InputType,
+      typename PolicyType::MappedType>;
 
   // Reverse mapping type.  Multiple inputs may map to a single output, hence
   // the need for std::vector.
@@ -200,4 +200,7 @@ using DatasetInfo = DatasetMapper<data::IncrementPolicy>;
 
 #include "dataset_mapper_impl.hpp"
 
+// Also include utility function.
+#include "check_categorical_param.hpp"
+
 #endif
