@@ -14,12 +14,14 @@
 #ifndef MLPACK_CORE_DATA_SAVE_HPP
 #define MLPACK_CORE_DATA_SAVE_HPP
 
+#include <mlpack/prereqs.hpp>
 #include <mlpack/core/util/log.hpp>
-#include <mlpack/core/arma_extend/arma_extend.hpp> // Includes Armadillo.
 #include <string>
 
 #include "format.hpp"
 #include "image_info.hpp"
+#include "detect_file_type.hpp"
+#include "save_image.hpp"
 
 namespace mlpack {
 namespace data /** Functions to load and save matrices. */ {
@@ -31,33 +33,40 @@ namespace data /** Functions to load and save matrices. */ {
  *
  * The supported types of files are the same as found in Armadillo:
  *
- *  - CSV (csv_ascii), denoted by .csv, or optionally .txt
- *  - ASCII (raw_ascii), denoted by .txt
- *  - Armadillo ASCII (arma_ascii), also denoted by .txt
- *  - PGM (pgm_binary), denoted by .pgm
- *  - PPM (ppm_binary), denoted by .ppm
- *  - Raw binary (raw_binary), denoted by .bin
- *  - Armadillo binary (arma_binary), denoted by .bin
- *  - HDF5 (hdf5_binary), denoted by .hdf5, .hdf, .h5, or .he5
+ *  - CSV (arma::csv_ascii), denoted by .csv, or optionally .txt
+ *  - ASCII (arma::raw_ascii), denoted by .txt
+ *  - Armadillo ASCII (arma::arma_ascii), also denoted by .txt
+ *  - PGM (arma::pgm_binary), denoted by .pgm
+ *  - PPM (arma::ppm_binary), denoted by .ppm
+ *  - Raw binary (arma::raw_binary), denoted by .bin
+ *  - Armadillo binary (arma::arma_binary), denoted by .bin
+ *  - HDF5 (arma::hdf5_binary), denoted by .hdf5, .hdf, .h5, or .he5
  *
- * If the file extension is not one of those types, an error will be given.  If
- * the 'fatal' parameter is set to true, a std::runtime_error exception will be
- * thrown upon failure.  If the 'transpose' parameter is set to true, the matrix
- * will be transposed before saving.  Generally, because mlpack stores matrices
- * in a column-major format and most datasets are stored on disk as row-major,
- * this parameter should be left at its default value of 'true'.
+ * By default, this function will try to automatically determine the format to
+ * save with based only on the filename's extension.  If you would prefer to
+ * specify a file type manually, override the default
+ * `inputSaveType` parameter with the correct type above (e.g.
+ * `arma::csv_ascii`.)
+ *
+ * If the 'fatal' parameter is set to true, a std::runtime_error exception will
+ * be thrown upon failure.  If the 'transpose' parameter is set to true, the
+ * matrix will be transposed before saving.  Generally, because mlpack stores
+ * matrices in a column-major format and most datasets are stored on disk as
+ * row-major, this parameter should be left at its default value of 'true'.
  *
  * @param filename Name of file to save to.
  * @param matrix Matrix to save into file.
  * @param fatal If an error should be reported as fatal (default false).
  * @param transpose If true, transpose the matrix before saving (default true).
+ * @param inputSaveType File type to save to (defaults to arma::auto_detect).
  * @return Boolean value indicating success or failure of save.
  */
 template<typename eT>
 bool Save(const std::string& filename,
           const arma::Mat<eT>& matrix,
           const bool fatal = false,
-          bool transpose = true);
+          bool transpose = true,
+          FileType inputSaveType = FileType::AutoDetect);
 
 /**
  * Saves a sparse matrix to file, guessing the filetype from the
@@ -96,14 +105,14 @@ bool Save(const std::string& filename,
  * used and the filetype cannot be determined, and error will be given.
  *
  * The supported types of files are the same as what is supported by the
- * boost::serialization library:
+ * cereal library:
  *
- *  - text, denoted by .txt
+ *  - json, denoted by .json
  *  - xml, denoted by .xml
  *  - binary, denoted by .bin
  *
  * The format parameter can take any of the values in the 'format' enum:
- * 'format::autodetect', 'format::text', 'format::xml', and 'format::binary'.
+ * 'format::autodetect', 'format::json', 'format::xml', and 'format::binary'.
  * The autodetect functionality operates on the file extension (so, "file.txt"
  * would be autodetected as text).
  *
@@ -122,44 +131,6 @@ bool Save(const std::string& filename,
           const bool fatal = false,
           format f = format::autodetect);
 
-/**
- * Save the image file from the given matrix.
- *
- * @param filename Name of the image file.
- * @param matrix Matrix to save the image from.
- * @param info An object of ImageInfo class.
- * @param fatal If an error should be reported as fatal (default false).
- * @return Boolean value indicating success or failure of load.
- */
-template<typename eT>
-bool Save(const std::string& filename,
-          arma::Mat<eT>& matrix,
-          ImageInfo& info,
-          const bool fatal = false);
-
-/**
- * Save the image file from the given matrix.
- *
- * @param files A vector consisting of filenames.
- * @param matrix Matrix to save the image from.
- * @param info An object of ImageInfo class.
- * @param fatal If an error should be reported as fatal (default false).
- * @return Boolean value indicating success or failure of load.
- */
-template<typename eT>
-bool Save(const std::vector<std::string>& files,
-          arma::Mat<eT>& matrix,
-          ImageInfo& info,
-          const bool fatal = false);
-
-/**
- * Helper function to save files.  Implementation in save_image.cpp.
- */
-bool SaveImage(const std::string& filename,
-               arma::Mat<unsigned char>& image,
-               ImageInfo& info,
-               const bool fatal = false);
-
 } // namespace data
 } // namespace mlpack
 
