@@ -24,7 +24,6 @@
 #include <mlpack/core/util/log.hpp>
 
 namespace mlpack {
-namespace kernel {
 
 /**
  * The p-spectrum string kernel.  Given a length p, the p-spectrum kernel finds
@@ -72,8 +71,9 @@ class PSpectrumStringKernel
    * @param datasets Sets of string data.
    * @param p The length of substrings to search.
    */
-  PSpectrumStringKernel(const std::vector<std::vector<std::string> >& datasets,
-                        const size_t p);
+  inline PSpectrumStringKernel(
+      const std::vector<std::vector<std::string>>& datasets,
+      const size_t p);
 
   /**
    * Evaluate the kernel for the string indices given.  As mentioned in the
@@ -110,7 +110,6 @@ class PSpectrumStringKernel
   size_t p;
 };
 
-} // namespace kernel
 } // namespace mlpack
 
 // Include implementation of templated Evaluate().
