@@ -3,8 +3,8 @@
  * @author Ryan Curtin
  * @author Conrad Sanderson
  *
- * ColumnCovariance(X) is same as cov(trans(X)) but without the cost
- * of computing trans(X)
+ * ColumnCovariance(X) is the same as cov(trans(X)) but without the cost of
+ * computing trans(X).
  *
  * mlpack is free software; you may redistribute it and/or modify it under the
  * terms of the 3-clause BSD license.  You should have received a copy of the
@@ -17,20 +17,18 @@
 #include <mlpack/prereqs.hpp>
 
 namespace mlpack {
-namespace math /** Miscellaneous math routines. */ {
 
 template<typename eT>
 inline
 arma::Mat<eT>
-ColumnCovariance(const arma::Mat<eT>& A, const size_t norm_type = 0);
+ColumnCovariance(const arma::Mat<eT>& A, const size_t normType = 0);
 
 template<typename T>
 inline
-arma::Mat< std::complex<T> >
-ColumnCovariance(const arma::Mat< std::complex<T> >& A,
-     const size_t norm_type = 0);
+arma::Mat<std::complex<T>>
+ColumnCovariance(const arma::Mat<std::complex<T>>& A,
+                 const size_t normType = 0);
 
-} // namespace math
 } // namespace mlpack
 
 // Include implementation
