@@ -2,7 +2,6 @@
  * @file core/tree/hrectbound_impl.hpp
  *
  * Implementation of hyper-rectangle bound policy class.
- * Template parameter Power is the metric to use; use 2 for Euclidean (L2).
  *
  * mlpack is free software; you may redistribute it and/or modify it under the
  * terms of the 3-clause BSD license.  You should have received a copy of the
@@ -17,13 +16,15 @@
 // In case it has not been included yet.
 #include "hrectbound.hpp"
 
+#include <mlpack/core/util/log.hpp>
+
 namespace mlpack {
 
 /**
  * Empty constructor.
  */
-template<typename MetricType, typename ElemType>
-inline HRectBound<MetricType, ElemType>::HRectBound() :
+template<typename DistanceType, typename ElemType>
+inline HRectBound<DistanceType, ElemType>::HRectBound() :
     dim(0),
     bounds(NULL),
     minWidth(0)
@@ -33,8 +34,8 @@ inline HRectBound<MetricType, ElemType>::HRectBound() :
  * Initializes to specified dimensionality with each dimension the empty
  * set.
  */
-template<typename MetricType, typename ElemType>
-inline HRectBound<MetricType, ElemType>::HRectBound(const size_t dimension) :
+template<typename DistanceType, typename ElemType>
+inline HRectBound<DistanceType, ElemType>::HRectBound(const size_t dimension) :
     dim(dimension),
     bounds(new RangeType<ElemType>[dim]),
     minWidth(0)
@@ -43,9 +44,9 @@ inline HRectBound<MetricType, ElemType>::HRectBound(const size_t dimension) :
 /**
  * Copy constructor necessary to prevent memory leaks.
  */
-template<typename MetricType, typename ElemType>
-inline HRectBound<MetricType, ElemType>::HRectBound(
-    const HRectBound<MetricType, ElemType>& other) :
+template<typename DistanceType, typename ElemType>
+inline HRectBound<DistanceType, ElemType>::HRectBound(
+    const HRectBound<DistanceType, ElemType>& other) :
     dim(other.Dim()),
     bounds(new RangeType<ElemType>[dim]),
     minWidth(other.MinWidth())
@@ -58,11 +59,11 @@ inline HRectBound<MetricType, ElemType>::HRectBound(
 /**
  * Same as the copy constructor.
  */
-template<typename MetricType, typename ElemType>
+template<typename DistanceType, typename ElemType>
 inline HRectBound<
-    MetricType,
-    ElemType>& HRectBound<MetricType,
-    ElemType>::operator=(const HRectBound<MetricType, ElemType>& other)
+    DistanceType,
+    ElemType>& HRectBound<DistanceType,
+    ElemType>::operator=(const HRectBound<DistanceType, ElemType>& other)
 {
   if (this == &other)
     return *this;
@@ -89,9 +90,9 @@ inline HRectBound<
 /**
  * Move constructor: take possession of another bound's information.
  */
-template<typename MetricType, typename ElemType>
-inline HRectBound<MetricType, ElemType>::HRectBound(
-    HRectBound<MetricType, ElemType>&& other) :
+template<typename DistanceType, typename ElemType>
+inline HRectBound<DistanceType, ElemType>::HRectBound(
+    HRectBound<DistanceType, ElemType>&& other) :
     dim(other.dim),
     bounds(other.bounds),
     minWidth(other.minWidth)
@@ -105,10 +106,10 @@ inline HRectBound<MetricType, ElemType>::HRectBound(
 /**
  * Move assignment operator.
  */
-template<typename MetricType, typename ElemType>
-inline HRectBound<MetricType, ElemType>&
-HRectBound<MetricType, ElemType>::operator=(
-    HRectBound<MetricType, ElemType>&& other)
+template<typename DistanceType, typename ElemType>
+inline HRectBound<DistanceType, ElemType>&
+HRectBound<DistanceType, ElemType>::operator=(
+    HRectBound<DistanceType, ElemType>&& other)
 {
   if (this != &other)
   {
@@ -125,8 +126,8 @@ HRectBound<MetricType, ElemType>::operator=(
 /**
  * Destructor: clean up memory.
  */
-template<typename MetricType, typename ElemType>
-inline HRectBound<MetricType, ElemType>::~HRectBound()
+template<typename DistanceType, typename ElemType>
+inline HRectBound<DistanceType, ElemType>::~HRectBound()
 {
   if (bounds)
     delete[] bounds;
@@ -135,8 +136,8 @@ inline HRectBound<MetricType, ElemType>::~HRectBound()
 /**
  * Resets all dimensions to the empty set.
  */
-template<typename MetricType, typename ElemType>
-inline void HRectBound<MetricType, ElemType>::Clear()
+template<typename DistanceType, typename ElemType>
+inline void HRectBound<DistanceType, ElemType>::Clear()
 {
   for (size_t i = 0; i < dim; ++i)
     bounds[i] = RangeType<ElemType>();
@@ -148,8 +149,8 @@ inline void HRectBound<MetricType, ElemType>::Clear()
  *
  * @param centroid Vector which the centroid will be written to.
  */
-template<typename MetricType, typename ElemType>
-inline void HRectBound<MetricType, ElemType>::Center(
+template<typename DistanceType, typename ElemType>
+inline void HRectBound<DistanceType, ElemType>::Center(
     arma::Col<ElemType>& center) const
 {
   // Set size correctly if necessary.
@@ -160,13 +161,24 @@ inline void HRectBound<MetricType, ElemType>::Center(
     center(i) = bounds[i].Mid();
 }
 
+/**
+ * Recompute the minimum width of the bound.
+ */
+template<typename DistanceType, typename ElemType>
+inline void HRectBound<DistanceType, ElemType>::RecomputeMinWidth()
+{
+  minWidth = std::numeric_limits<ElemType>::max();
+  for (size_t i = 0; i < dim; ++i)
+    minWidth = std::min(minWidth, bounds[i].Width());
+}
+
 /**
  * Calculate the volume of the hyperrectangle.
  *
  * @return Volume of the hyperrectangle.
  */
-template<typename MetricType, typename ElemType>
-inline ElemType HRectBound<MetricType, ElemType>::Volume() const
+template<typename DistanceType, typename ElemType>
+inline ElemType HRectBound<DistanceType, ElemType>::Volume() const
 {
   ElemType volume = 1.0;
   for (size_t i = 0; i < dim; ++i)
@@ -183,9 +195,9 @@ inline ElemType HRectBound<MetricType, ElemType>::Volume() const
 /**
  * Calculates minimum bound-to-point squared distance.
  */
-template<typename MetricType, typename ElemType>
+template<typename DistanceType, typename ElemType>
 template<typename VecType>
-inline ElemType HRectBound<MetricType, ElemType>::MinDistance(
+inline ElemType HRectBound<DistanceType, ElemType>::MinDistance(
     const VecType& point,
     typename std::enable_if_t<IsVector<VecType>::value>* /* junk */) const
 {
@@ -202,17 +214,17 @@ inline ElemType HRectBound<MetricType, ElemType>::MinDistance(
     // Since only one of 'lower' or 'higher' is negative, if we add each's
     // absolute value to itself and then sum those two, our result is the
     // nonnegative half of the equation times two; then we raise to power Power.
-    if (MetricType::Power == 1)
+    if (DistanceType::Power == 1)
       sum += (lower + std::fabs(lower)) + (higher + std::fabs(higher));
-    else if (MetricType::Power == 2)
+    else if (DistanceType::Power == 2)
     {
       ElemType dist = (lower + std::fabs(lower)) + (higher + std::fabs(higher));
       sum += dist * dist;
     }
     else
     {
-      sum += pow((lower + fabs(lower)) + (higher + fabs(higher)),
-          (ElemType) MetricType::Power);
+      sum += std::pow((lower + std::fabs(lower)) + (higher + std::fabs(higher)),
+          (ElemType) DistanceType::Power);
     }
   }
 
@@ -220,31 +232,31 @@ inline ElemType HRectBound<MetricType, ElemType>::MinDistance(
   // to be); then cancel out the constant of 2 (which may have been squared now)
   // that was introduced earlier.  The compiler should optimize out the if
   // statement entirely.
-  if (MetricType::Power == 1)
+  if (DistanceType::Power == 1)
     return sum * 0.5;
-  else if (MetricType::Power == 2)
+  else if (DistanceType::Power == 2)
   {
-    if (MetricType::TakeRoot)
+    if (DistanceType::TakeRoot)
       return (ElemType) std::sqrt(sum) * 0.5;
     else
       return sum * 0.25;
   }
   else
   {
-    if (MetricType::TakeRoot)
-      return (ElemType) pow((double) sum,
-          1.0 / (double) MetricType::Power) / 2.0;
+    if (DistanceType::TakeRoot)
+      return (ElemType) std::pow((double) sum,
+          1.0 / (double) DistanceType::Power) / 2.0;
     else
-      return sum / pow(2.0, MetricType::Power);
+      return sum / std::pow(2.0, DistanceType::Power);
   }
 }
 
 /**
  * Calculates minimum bound-to-bound squared distance.
  */
-template<typename MetricType, typename ElemType>
-ElemType HRectBound<MetricType, ElemType>::MinDistance(const HRectBound& other)
-    const
+template<typename DistanceType, typename ElemType>
+ElemType HRectBound<DistanceType, ElemType>::MinDistance(
+    const HRectBound& other) const
 {
   Log::Assert(dim == other.dim);
 
@@ -262,17 +274,17 @@ ElemType HRectBound<MetricType, ElemType>::MinDistance(const HRectBound& other)
     //   (x * 2)^2 / 4 = x^2
 
     // The compiler should optimize out this if statement entirely.
-    if (MetricType::Power == 1)
+    if (DistanceType::Power == 1)
       sum += (lower + std::fabs(lower)) + (higher + std::fabs(higher));
-    else if (MetricType::Power == 2)
+    else if (DistanceType::Power == 2)
     {
       ElemType dist = (lower + std::fabs(lower)) + (higher + std::fabs(higher));
       sum += dist * dist;
     }
     else
     {
-      sum += pow((lower + fabs(lower)) + (higher + fabs(higher)),
-          (ElemType) MetricType::Power);
+      sum += std::pow((lower + std::fabs(lower)) + (higher + std::fabs(higher)),
+          (ElemType) DistanceType::Power);
     }
 
     // Move bound pointers.
@@ -281,31 +293,31 @@ ElemType HRectBound<MetricType, ElemType>::MinDistance(const HRectBound& other)
   }
 
   // The compiler should optimize out this if statement entirely.
-  if (MetricType::Power == 1)
+  if (DistanceType::Power == 1)
     return sum * 0.5;
-  else if (MetricType::Power == 2)
+  else if (DistanceType::Power == 2)
   {
-    if (MetricType::TakeRoot)
+    if (DistanceType::TakeRoot)
       return (ElemType) std::sqrt(sum) * 0.5;
     else
       return sum * 0.25;
   }
   else
   {
-    if (MetricType::TakeRoot)
-      return (ElemType) pow((double) sum,
-          1.0 / (double) MetricType::Power) / 2.0;
+    if (DistanceType::TakeRoot)
+      return (ElemType) std::pow((double) sum,
+          1.0 / (double) DistanceType::Power) / 2.0;
     else
-      return sum / pow(2.0, MetricType::Power);
+      return sum / std::pow(2.0, DistanceType::Power);
   }
 }
 
 /**
  * Calculates maximum bound-to-point squared distance.
  */
-template<typename MetricType, typename ElemType>
+template<typename DistanceType, typename ElemType>
 template<typename VecType>
-inline ElemType HRectBound<MetricType, ElemType>::MaxDistance(
+inline ElemType HRectBound<DistanceType, ElemType>::MaxDistance(
     const VecType& point,
     typename std::enable_if_t<IsVector<VecType>::value>* /* junk */) const
 {
@@ -319,23 +331,24 @@ inline ElemType HRectBound<MetricType, ElemType>::MaxDistance(
         fabs(bounds[d].Hi() - point[d]));
 
     // The compiler should optimize out this if statement entirely.
-    if (MetricType::Power == 1)
+    if (DistanceType::Power == 1)
       sum += v; // v is non-negative.
-    else if (MetricType::Power == 2)
+    else if (DistanceType::Power == 2)
       sum += v * v;
     else
-      sum += std::pow(v, (ElemType) MetricType::Power);
+      sum += std::pow(v, (ElemType) DistanceType::Power);
   }
 
   // The compiler should optimize out this if statement entirely.
-  if (MetricType::TakeRoot)
+  if (DistanceType::TakeRoot)
   {
-    if (MetricType::Power == 1)
+    if (DistanceType::Power == 1)
       return sum;
-    else if (MetricType::Power == 2)
+    else if (DistanceType::Power == 2)
       return (ElemType) std::sqrt(sum);
     else
-      return (ElemType) pow((double) sum, 1.0 / (double) MetricType::Power);
+      return (ElemType) std::pow((double) sum, 1.0 /
+          (double) DistanceType::Power);
   }
   else
     return sum;
@@ -344,8 +357,8 @@ inline ElemType HRectBound<MetricType, ElemType>::MaxDistance(
 /**
  * Computes maximum distance.
  */
-template<typename MetricType, typename ElemType>
-inline ElemType HRectBound<MetricType, ElemType>::MaxDistance(
+template<typename DistanceType, typename ElemType>
+inline ElemType HRectBound<DistanceType, ElemType>::MaxDistance(
     const HRectBound& other)
     const
 {
@@ -360,23 +373,24 @@ inline ElemType HRectBound<MetricType, ElemType>::MaxDistance(
         fabs(bounds[d].Hi() - other.bounds[d].Lo()));
 
     // The compiler should optimize out this if statement entirely.
-    if (MetricType::Power == 1)
+    if (DistanceType::Power == 1)
       sum += v; // v is non-negative.
-    else if (MetricType::Power == 2)
+    else if (DistanceType::Power == 2)
       sum += v * v;
     else
-      sum += std::pow(v, (ElemType) MetricType::Power);
+      sum += std::pow(v, (ElemType) DistanceType::Power);
   }
 
   // The compiler should optimize out this if statement entirely.
-  if (MetricType::TakeRoot)
+  if (DistanceType::TakeRoot)
   {
-    if (MetricType::Power == 1)
+    if (DistanceType::Power == 1)
       return sum;
-    else if (MetricType::Power == 2)
+    else if (DistanceType::Power == 2)
       return (ElemType) std::sqrt(sum);
     else
-      return (ElemType) pow((double) sum, 1.0 / (double) MetricType::Power);
+      return (ElemType) std::pow((double) sum, 1.0 /
+          (double) DistanceType::Power);
   }
   else
     return sum;
@@ -385,9 +399,9 @@ inline ElemType HRectBound<MetricType, ElemType>::MaxDistance(
 /**
  * Calculates minimum and maximum bound-to-bound squared distance.
  */
-template<typename MetricType, typename ElemType>
+template<typename DistanceType, typename ElemType>
 inline RangeType<ElemType>
-HRectBound<MetricType, ElemType>::RangeDistance(
+HRectBound<DistanceType, ElemType>::RangeDistance(
     const HRectBound& other) const
 {
   ElemType loSum = 0;
@@ -413,48 +427,52 @@ HRectBound<MetricType, ElemType>::RangeDistance(
     }
 
     // The compiler should optimize out this if statement entirely.
-    if (MetricType::Power == 1)
+    if (DistanceType::Power == 1)
     {
       loSum += vLo; // vLo is non-negative.
       hiSum += vHi; // vHi is non-negative.
     }
-    else if (MetricType::Power == 2)
+    else if (DistanceType::Power == 2)
     {
       loSum += vLo * vLo;
       hiSum += vHi * vHi;
     }
     else
     {
-      loSum += std::pow(vLo, (ElemType) MetricType::Power);
-      hiSum += std::pow(vHi, (ElemType) MetricType::Power);
+      loSum += std::pow(vLo, (ElemType) DistanceType::Power);
+      hiSum += std::pow(vHi, (ElemType) DistanceType::Power);
     }
   }
 
-  if (MetricType::TakeRoot)
+  if (DistanceType::TakeRoot)
   {
-    if (MetricType::Power == 1)
+    if (DistanceType::Power == 1)
       return RangeType<ElemType>(loSum, hiSum);
-    else if (MetricType::Power == 2)
+    else if (DistanceType::Power == 2)
       return RangeType<ElemType>((ElemType) std::sqrt(loSum),
                                        (ElemType) std::sqrt(hiSum));
     else
     {
       return RangeType<ElemType>(
-          (ElemType) pow((double) loSum, 1.0 / (double) MetricType::Power),
-          (ElemType) pow((double) hiSum, 1.0 / (double) MetricType::Power));
+          (ElemType) std::pow((double) loSum,
+              1.0 / (double) DistanceType::Power),
+          (ElemType) std::pow((double) hiSum,
+              1.0 / (double) DistanceType::Power));
     }
   }
   else
+  {
     return RangeType<ElemType>(loSum, hiSum);
+  }
 }
 
 /**
  * Calculates minimum and maximum bound-to-point squared distance.
  */
-template<typename MetricType, typename ElemType>
+template<typename DistanceType, typename ElemType>
 template<typename VecType>
 inline RangeType<ElemType>
-HRectBound<MetricType, ElemType>::RangeDistance(
+HRectBound<DistanceType, ElemType>::RangeDistance(
     const VecType& point,
     typename std::enable_if_t<IsVector<VecType>::value>* /* junk */) const
 {
@@ -489,35 +507,37 @@ HRectBound<MetricType, ElemType>::RangeDistance(
     }
 
     // The compiler should optimize out this if statement entirely.
-    if (MetricType::Power == 1)
+    if (DistanceType::Power == 1)
     {
       loSum += vLo; // vLo is non-negative.
       hiSum += vHi; // vHi is non-negative.
     }
-    else if (MetricType::Power == 2)
+    else if (DistanceType::Power == 2)
     {
       loSum += vLo * vLo;
       hiSum += vHi * vHi;
     }
     else
     {
-      loSum += std::pow(vLo, (ElemType) MetricType::Power);
-      hiSum += std::pow(vHi, (ElemType) MetricType::Power);
+      loSum += std::pow(vLo, (ElemType) DistanceType::Power);
+      hiSum += std::pow(vHi, (ElemType) DistanceType::Power);
     }
   }
 
-  if (MetricType::TakeRoot)
+  if (DistanceType::TakeRoot)
   {
-    if (MetricType::Power == 1)
+    if (DistanceType::Power == 1)
       return RangeType<ElemType>(loSum, hiSum);
-    else if (MetricType::Power == 2)
+    else if (DistanceType::Power == 2)
       return RangeType<ElemType>((ElemType) std::sqrt(loSum),
-                                       (ElemType) std::sqrt(hiSum));
+                                 (ElemType) std::sqrt(hiSum));
     else
     {
       return RangeType<ElemType>(
-          (ElemType) pow((double) loSum, 1.0 / (double) MetricType::Power),
-          (ElemType) pow((double) hiSum, 1.0 / (double) MetricType::Power));
+          (ElemType) std::pow((double) loSum,
+              1.0 / (double) DistanceType::Power),
+          (ElemType) std::pow((double) hiSum,
+              1.0 / (double) DistanceType::Power));
     }
   }
   else
@@ -527,10 +547,10 @@ HRectBound<MetricType, ElemType>::RangeDistance(
 /**
  * Expands this region to include a new point.
  */
-template<typename MetricType, typename ElemType>
+template<typename DistanceType, typename ElemType>
 template<typename MatType>
-inline HRectBound<MetricType, ElemType>&
-HRectBound<MetricType, ElemType>::operator|=(const MatType& data)
+inline HRectBound<DistanceType, ElemType>&
+HRectBound<DistanceType, ElemType>::operator|=(const MatType& data)
 {
   Log::Assert(data.n_rows == dim);
 
@@ -552,9 +572,9 @@ HRectBound<MetricType, ElemType>::operator|=(const MatType& data)
 /**
  * Expands this region to encompass another bound.
  */
-template<typename MetricType, typename ElemType>
-inline HRectBound<MetricType, ElemType>&
-HRectBound<MetricType, ElemType>::operator|=(const HRectBound& other)
+template<typename DistanceType, typename ElemType>
+inline HRectBound<DistanceType, ElemType>&
+HRectBound<DistanceType, ElemType>::operator|=(const HRectBound& other)
 {
   assert(other.dim == dim);
 
@@ -573,9 +593,9 @@ HRectBound<MetricType, ElemType>::operator|=(const HRectBound& other)
 /**
  * Determines if a point is within this bound.
  */
-template<typename MetricType, typename ElemType>
+template<typename DistanceType, typename ElemType>
 template<typename VecType>
-inline bool HRectBound<MetricType, ElemType>::Contains(
+inline bool HRectBound<DistanceType, ElemType>::Contains(
     const VecType& point) const
 {
   for (size_t i = 0; i < point.n_elem; ++i)
@@ -590,8 +610,8 @@ inline bool HRectBound<MetricType, ElemType>::Contains(
 /**
  * Determines if this bound partially contains a bound.
  */
-template<typename MetricType, typename ElemType>
-inline bool HRectBound<MetricType, ElemType>::Contains(
+template<typename DistanceType, typename ElemType>
+inline bool HRectBound<DistanceType, ElemType>::Contains(
     const HRectBound& bound) const
 {
   for (size_t i = 0; i < dim; ++i)
@@ -610,11 +630,11 @@ inline bool HRectBound<MetricType, ElemType>::Contains(
 /**
  * Returns the intersection of this bound and another.
  */
-template<typename MetricType, typename ElemType>
-inline HRectBound<MetricType, ElemType>
-HRectBound<MetricType, ElemType>::operator&(const HRectBound& bound) const
+template<typename DistanceType, typename ElemType>
+inline HRectBound<DistanceType, ElemType>
+HRectBound<DistanceType, ElemType>::operator&(const HRectBound& bound) const
 {
-  HRectBound<MetricType, ElemType> result(dim);
+  HRectBound<DistanceType, ElemType> result(dim);
 
   for (size_t k = 0; k < dim; ++k)
   {
@@ -627,9 +647,9 @@ HRectBound<MetricType, ElemType>::operator&(const HRectBound& bound) const
 /**
  * Intersects this bound with another.
  */
-template<typename MetricType, typename ElemType>
-inline HRectBound<MetricType, ElemType>&
-HRectBound<MetricType, ElemType>::operator&=(const HRectBound& bound)
+template<typename DistanceType, typename ElemType>
+inline HRectBound<DistanceType, ElemType>&
+HRectBound<DistanceType, ElemType>::operator&=(const HRectBound& bound)
 {
   for (size_t k = 0; k < dim; ++k)
   {
@@ -642,8 +662,8 @@ HRectBound<MetricType, ElemType>::operator&=(const HRectBound& bound)
 /**
  * Returns the volume of overlap of this bound and another.
  */
-template<typename MetricType, typename ElemType>
-inline ElemType HRectBound<MetricType, ElemType>::Overlap(
+template<typename DistanceType, typename ElemType>
+inline ElemType HRectBound<DistanceType, ElemType>::Overlap(
     const HRectBound& bound) const
 {
   ElemType volume = 1.0;
@@ -653,7 +673,7 @@ inline ElemType HRectBound<MetricType, ElemType>::Overlap(
     ElemType lo = std::max(bounds[k].Lo(), bound.bounds[k].Lo());
     ElemType hi = std::min(bounds[k].Hi(), bound.bounds[k].Hi());
 
-    if ( hi <= lo)
+    if (hi <= lo)
       return 0;
 
     volume *= hi - lo;
@@ -664,31 +684,31 @@ inline ElemType HRectBound<MetricType, ElemType>::Overlap(
 /**
  * Returns the diameter of the hyperrectangle (that is, the longest diagonal).
  */
-template<typename MetricType, typename ElemType>
-inline ElemType HRectBound<MetricType, ElemType>::Diameter() const
+template<typename DistanceType, typename ElemType>
+inline ElemType HRectBound<DistanceType, ElemType>::Diameter() const
 {
   ElemType d = 0;
   for (size_t i = 0; i < dim; ++i)
     d += std::pow(bounds[i].Hi() - bounds[i].Lo(),
-        (ElemType) MetricType::Power);
+        (ElemType) DistanceType::Power);
 
-  if (MetricType::TakeRoot)
-    return (ElemType) std::pow((double) d, 1.0 / (double) MetricType::Power);
+  if (DistanceType::TakeRoot)
+    return (ElemType) std::pow((double) d, 1.0 / (double) DistanceType::Power);
   else
     return d;
 }
 
 //! Serialize the bound object.
-template<typename MetricType, typename ElemType>
+template<typename DistanceType, typename ElemType>
 template<typename Archive>
-void HRectBound<MetricType, ElemType>::serialize(
+void HRectBound<DistanceType, ElemType>::serialize(
     Archive& ar,
     const uint32_t /* version */)
 {
   // We can't serialize a raw array directly, so wrap it.
   ar(CEREAL_POINTER_ARRAY(bounds, dim));
   ar(CEREAL_NVP(minWidth));
-  ar(CEREAL_NVP(metric));
+  ar(CEREAL_NVP(distance));
 }
 
 } // namespace mlpack
