@@ -16,7 +16,6 @@
 #include <mlpack/prereqs.hpp>
 
 namespace mlpack {
-namespace tree /** Trees and tree-building procedures. */ {
 
 /**
  * The RPlusTreeSplit class performs the split process of a node on overflow.
@@ -32,7 +31,7 @@ template<typename SplitPolicyType,
 class RPlusTreeSplit
 {
  public:
-  typedef SplitPolicyType SplitPolicy;
+  using SplitPolicy = SplitPolicyType;
   /**
    * Split a leaf node using the "default" algorithm.  If necessary, this split
    * will propagate upwards through the tree.
@@ -125,7 +124,6 @@ class RPlusTreeSplit
   static void InsertNodeIntoTree(TreeType* destTree, TreeType* srcNode);
 };
 
-} // namespace tree
 } // namespace mlpack
 
 // Include implementation
