@@ -22,7 +22,6 @@
 #include "no_auxiliary_information.hpp"
 
 namespace mlpack {
-namespace tree /** Trees and tree-building procedures. */ {
 
 /**
  * A rectangle type tree tree, such as an R-tree or X-tree.  Once the
@@ -32,7 +31,7 @@ namespace tree /** Trees and tree-building procedures. */ {
  *
  * This tree does allow growth, so you can add and delete nodes from it.
  *
- * @tparam MetricType This *must* be EuclideanDistance, but the template
+ * @tparam DistanceType This *must* be EuclideanDistance, but the template
  *     parameter is required to satisfy the TreeType API.
  * @tparam StatisticType Extra data contained in the node.  See statistic.hpp
  *     for the necessary skeleton interface.
@@ -44,7 +43,7 @@ namespace tree /** Trees and tree-building procedures. */ {
  *    in the node. This information depends on the type of the RectangleTree.
  */
 
-template<typename MetricType = metric::EuclideanDistance,
+template<typename DistanceType = EuclideanDistance,
          typename StatisticType = EmptyStatistic,
          typename MatType = arma::mat,
          typename SplitType = RTreeSplit,
@@ -53,17 +52,17 @@ template<typename MetricType = metric::EuclideanDistance,
              NoAuxiliaryInformation>
 class RectangleTree
 {
-  // The metric *must* be the euclidean distance.
-  static_assert(boost::is_same<MetricType, metric::EuclideanDistance>::value,
-      "RectangleTree: MetricType must be metric::EuclideanDistance.");
+  // The distance metric *must* be the euclidean distance.
+  static_assert(std::is_same_v<DistanceType, EuclideanDistance>,
+      "RectangleTree: DistanceType must be EuclideanDistance.");
 
  public:
   //! So other classes can use TreeType::Mat.
-  typedef MatType Mat;
+  using Mat = MatType;
   //! The element type held by the matrix type.
-  typedef typename MatType::elem_type ElemType;
+  using ElemType = typename MatType::elem_type;
   //! The auxiliary information type held by the tree.
-  typedef AuxiliaryInformationType<RectangleTree> AuxiliaryInformation;
+  using AuxiliaryInformation = AuxiliaryInformationType<RectangleTree>;
  private:
   //! The max number of child nodes a non-leaf node can have.
   size_t maxNumChildren;
@@ -90,7 +89,7 @@ class RectangleTree
   //! The minimum leaf size.
   size_t minLeafSize;
   //! The bound object for this node.
-  bound::HRectBound<metric::EuclideanDistance, ElemType> bound;
+  HRectBound<EuclideanDistance, ElemType> bound;
   //! Any extra data contained in the node.
   StatisticType stat;
   //! The distance from the centroid of this node to the centroid of the parent.
@@ -201,12 +200,12 @@ class RectangleTree
   RectangleTree& operator=(RectangleTree&& other);
 
   /**
-   * Construct the tree from a boost::serialization archive.
+   * Construct the tree from a cereal archive.
    */
   template<typename Archive>
   RectangleTree(
       Archive& ar,
-      const typename std::enable_if_t<Archive::is_loading::value>* = 0);
+      const typename std::enable_if_t<cereal::is_loading<Archive>()>* = 0);
 
   /**
    * Deletes this node, deallocating the memory for the children and calling
@@ -312,9 +311,9 @@ class RectangleTree
   RectangleTree* FindByBeginCount(size_t begin, size_t count);
 
   //! Return the bound object for this node.
-  const bound::HRectBound<MetricType>& Bound() const { return bound; }
+  const HRectBound<DistanceType>& Bound() const { return bound; }
   //! Modify the bound object for this node.
-  bound::HRectBound<MetricType>& Bound() { return bound; }
+  HRectBound<DistanceType>& Bound() { return bound; }
 
   //! Return the statistic object for this node.
   const StatisticType& Stat() const { return stat; }
@@ -361,8 +360,12 @@ class RectangleTree
   //! Modify the dataset which the tree is built on.  Be careful!
   MatType& Dataset() { return const_cast<MatType&>(*dataset); }
 
-  //! Get the metric which the tree uses.
-  MetricType Metric() const { return MetricType(); }
+  //! Get the distance metric which the tree uses.
+  [[deprecated("Will be removed in mlpack 5.0.0; use Distance()")]]
+  DistanceType Metric() const { return DistanceType(); }
+
+  //! Get the distance metric which the tree uses.
+  DistanceType Distance() const { return DistanceType(); }
 
   //! Get the centroid of the node and store it in the given vector.
   void Center(arma::vec& center) { bound.Center(center); }
@@ -496,7 +499,7 @@ class RectangleTree
   }
 
   //! Return the minimum and maximum distance to another node.
-  math::RangeType<ElemType> RangeDistance(const RectangleTree& other) const
+  RangeType<ElemType> RangeDistance(const RectangleTree& other) const
   {
     return bound.RangeDistance(other.Bound());
   }
@@ -521,7 +524,7 @@ class RectangleTree
 
   //! Return the minimum and maximum distance to another point.
   template<typename VecType>
-  math::RangeType<ElemType> RangeDistance(
+  RangeType<ElemType> RangeDistance(
       const VecType& point,
       typename std::enable_if_t<IsVector<VecType>::value>* = 0) const
   {
@@ -567,14 +570,14 @@ class RectangleTree
  protected:
   /**
    * A default constructor.  This is meant to only be used with
-   * boost::serialization, which is allowed with the friend declaration below.
+   * cereal, which is allowed with the friend declaration below.
    * This does not return a valid tree!  This method must be protected, so that
    * the serialization shim can work with the default constructor.
    */
   RectangleTree();
 
   //! Friend access is given for the default constructor.
-  friend class boost::serialization::access;
+  friend class cereal::access;
 
   //! Give friend access for DescentType.
   friend DescentType;
@@ -619,7 +622,7 @@ class RectangleTree
    *      shrinking.
    * @return true if the bound needed to be changed, false if it did not.
    */
-  bool ShrinkBoundForBound(const bound::HRectBound<MetricType>& changedBound);
+  bool ShrinkBoundForBound(const HRectBound<DistanceType>& changedBound);
 
   /**
    * Make an exact copy of this node, pointers and everything.
@@ -630,10 +633,9 @@ class RectangleTree
    * Serialize the tree.
    */
   template<typename Archive>
-  void serialize(Archive& ar, const unsigned int /* version */);
+  void serialize(Archive& ar, const uint32_t /* version */);
 };
 
-} // namespace tree
 } // namespace mlpack
 
 // Include implementation.
