@@ -15,8 +15,6 @@
 // In case it hasn't been included yet.
 #include "ffn.hpp"
 
-#include "make_alias.hpp"
-
 namespace mlpack {
 
 template<typename OutputLayerType,
@@ -194,7 +192,7 @@ void FFN<
     OutputLayerType,
     InitializationRuleType,
     MatType
->::Predict(MatType predictors, MatType& results, const size_t batchSize)
+>::Predict(const MatType& predictors, MatType& results, const size_t batchSize)
 {
   // Ensure that the network is configured correctly.
   CheckNetwork("FFN::Predict()", predictors.n_rows, true, false);
@@ -206,10 +204,12 @@ void FFN<
     const size_t effectiveBatchSize = std::min(batchSize,
         size_t(predictors.n_cols) - i);
 
-    MatType predictorAlias(predictors.colptr(i), predictors.n_rows,
-        effectiveBatchSize, false, true);
-    MatType resultAlias(results.colptr(i), results.n_rows,
-        effectiveBatchSize, false, true);
+    MatType predictorAlias, resultAlias;
+
+    MakeAlias(predictorAlias, predictors, predictors.n_rows,
+        effectiveBatchSize, i * predictors.n_rows);
+    MakeAlias(resultAlias, results, results.n_rows, effectiveBatchSize,
+        i * results.n_rows);
 
     network.Forward(predictorAlias, resultAlias);
   }
@@ -251,9 +251,10 @@ void FFN<
   }
   else if (inputDimensions.size() > 0)
   {
-    const size_t inputDims = std::accumulate(inputDimensions.begin(),
-        inputDimensions.end(), 0);
-    CheckNetwork("FFN::Reset()", inputDims, true, false);
+    size_t inputDim = inputDimensions[0];
+    for (size_t i = 1; i < inputDimensions.size(); i++)
+      inputDim *= inputDimensions[i];
+    CheckNetwork("FFN::Reset()", inputDim, true, false);
   }
   else
   {
@@ -335,7 +336,7 @@ typename MatType::elem_type FFN<
   outputLayer.Backward(networkOutput, targets, error);
 
   // Perform the backward pass.
-  network.Backward(networkOutput, error, networkDelta);
+  network.Backward(inputs, networkOutput, error, networkDelta);
 
   // Now compute the gradients.
   // The gradient should have the same size as the parameters.
@@ -448,10 +449,14 @@ typename MatType::elem_type FFN<
   // Set networkOutput to the right size if needed, then perform the forward
   // pass.
   networkOutput.set_size(network.OutputSize(), batchSize);
-  network.Forward(predictors.cols(begin, begin + batchSize - 1), networkOutput);
+  MatType predictorsBatch, responsesBatch;
+  MakeAlias(predictorsBatch, predictors, predictors.n_rows, batchSize,
+      begin * predictors.n_rows);
+  MakeAlias(responsesBatch, responses, responses.n_rows, batchSize,
+      begin * responses.n_rows);
+  network.Forward(predictorsBatch, networkOutput);
 
-  return outputLayer.Forward(networkOutput,
-      responses.cols(begin, begin + batchSize - 1)) + network.Loss();
+  return outputLayer.Forward(networkOutput, responsesBatch) + network.Loss();
 }
 
 template<typename OutputLayerType,
@@ -465,9 +470,10 @@ typename MatType::elem_type FFN<
 {
   typename MatType::elem_type res = 0;
   res += EvaluateWithGradient(parameters, 0, gradient, 1);
+  MatType tmpGradient(gradient.n_rows, gradient.n_cols,
+      GetFillType<MatType>::none);
   for (size_t i = 1; i < predictors.n_cols; ++i)
   {
-    arma::mat tmpGradient(gradient.n_rows, gradient.n_cols);
     res += EvaluateWithGradient(parameters, i, tmpGradient, 1);
     gradient += tmpGradient;
   }
@@ -493,24 +499,29 @@ typename MatType::elem_type FFN<
   // pass.
   networkOutput.set_size(network.OutputSize(), batchSize);
 
-  network.Forward(predictors.cols(begin, begin + batchSize - 1), networkOutput);
+  // Alias the batches so we don't copy memory.
+  MatType predictorsBatch, responsesBatch;
+  MakeAlias(predictorsBatch, predictors, predictors.n_rows,
+      batchSize, begin * predictors.n_rows);
+  MakeAlias(responsesBatch, responses, responses.n_rows,
+      batchSize, begin * responses.n_rows);
+
+  network.Forward(predictorsBatch, networkOutput);
 
   const typename MatType::elem_type obj = outputLayer.Forward(networkOutput,
-      responses.cols(begin, begin + batchSize - 1)) + network.Loss();
+      responsesBatch) + network.Loss();
 
   // Now perform the backward pass.
-  outputLayer.Backward(networkOutput,
-      responses.cols(begin, begin + batchSize - 1), error);
+  outputLayer.Backward(networkOutput, responsesBatch, error);
 
   // The delta should have the same size as the input.
   networkDelta.set_size(predictors.n_rows, batchSize);
-  network.Backward(networkOutput, error, networkDelta);
+  network.Backward(predictorsBatch, networkOutput, error, networkDelta);
 
   // Now compute the gradients.
   // The gradient should have the same size as the parameters.
   gradient.set_size(parameters.n_rows, parameters.n_cols);
-  network.Gradient(predictors.cols(begin, begin + batchSize - 1), error,
-      gradient);
+  network.Gradient(predictorsBatch, error, gradient);
 
   return obj;
 }
@@ -589,7 +600,7 @@ void FFN<
       "FFN::SetLayerMemory(): total layer weight size does not match parameter "
       "size!");
 
-  network.SetWeights(parameters.memptr());
+  network.SetWeights(parameters);
   layerMemoryIsSet = true;
 }
 
@@ -683,9 +694,8 @@ template<typename OutputLayerType,
          typename InitializationRuleType,
          typename MatType>
 template<typename OptimizerType>
-typename std::enable_if<
-    ens::traits::HasMaxIterationsSignature<OptimizerType>::value, void
->::type
+std::enable_if_t<
+    ens::traits::HasMaxIterationsSignature<OptimizerType>::value, void>
 FFN<
     OutputLayerType,
     InitializationRuleType,
@@ -707,9 +717,8 @@ template<typename OutputLayerType,
          typename InitializationRuleType,
          typename MatType>
 template<typename OptimizerType>
-typename std::enable_if<
-    !ens::traits::HasMaxIterationsSignature<OptimizerType>::value, void
->::type
+std::enable_if_t<
+    !ens::traits::HasMaxIterationsSignature<OptimizerType>::value, void>
 FFN<
     OutputLayerType,
     InitializationRuleType,
