@@ -272,17 +272,17 @@ void ConvolutionType<
     BackwardConvolutionRule,
     GradientConvolutionRule,
     MatType
->::SetWeights(typename MatType::elem_type* weightPtr)
+>::SetWeights(const MatType& weightsIn)
 {
-  MakeAlias(weight, weightPtr, kernelWidth, kernelHeight, maps * inMaps);
+  MakeAlias(weight, weightsIn, kernelWidth, kernelHeight, maps * inMaps);
   if (useBias)
   {
-    MakeAlias(bias, weightPtr + weight.n_elem, maps, 1);
-    MakeAlias(weights, weightPtr, weight.n_elem + bias.n_elem, 1);
+    MakeAlias(bias, weightsIn, maps, 1, weight.n_elem);
+    MakeAlias(weights, weightsIn, weight.n_elem + bias.n_elem, 1);
   }
   else
   {
-    MakeAlias(weights, weightPtr, weight.n_elem, 1);
+    MakeAlias(weights, weightsIn, weight.n_elem, 1);
   }
 }
 
@@ -313,12 +313,11 @@ void ConvolutionType<
     padding.Forward(input, inputPadded);
   }
 
-  arma::Cube<typename MatType::elem_type> inputTemp;
-  MakeAlias(inputTemp,
-      const_cast<MatType&>(usingPadding ? inputPadded : input).memptr(),
-      paddedRows, paddedCols, inMaps * higherInDimensions * batchSize);
+  CubeType inputTemp;
+  MakeAlias(inputTemp, (usingPadding ? inputPadded : input), paddedRows,
+      paddedCols, inMaps * higherInDimensions * batchSize);
 
-  MakeAlias(outputTemp, output.memptr(), this->outputDimensions[0],
+  MakeAlias(outputTemp, output, this->outputDimensions[0],
       this->outputDimensions[1], maps * higherInDimensions * batchSize);
   outputTemp.zeros();
 
@@ -370,36 +369,39 @@ void ConvolutionType<
     GradientConvolutionRule,
     MatType
 >::Backward(
-    const MatType& /* input */, const MatType& gy, MatType& g)
+    const MatType& /* input */,
+    const MatType& /* output */,
+    const MatType& gy,
+    MatType& g)
 {
-  arma::Cube<typename MatType::elem_type> mappedError;
-  MakeAlias(mappedError, ((MatType&) gy).memptr(), this->outputDimensions[0],
+  CubeType mappedError;
+  MakeAlias(mappedError, gy, this->outputDimensions[0],
       this->outputDimensions[1], higherInDimensions * maps * batchSize);
 
-  MakeAlias(gTemp, g.memptr(), this->inputDimensions[0],
-      this->inputDimensions[1], inMaps * higherInDimensions * batchSize);
+  MakeAlias(gTemp, g, this->inputDimensions[0], this->inputDimensions[1],
+      inMaps * higherInDimensions * batchSize);
   gTemp.zeros();
 
   const bool usingPadding =
       (padWLeft != 0 || padWRight != 0 || padHTop != 0 || padHBottom != 0);
 
   // To perform the backward pass, we need to rotate all the filters.
-  arma::Cube<typename MatType::elem_type> rotatedFilters(weight.n_rows,
+  CubeType rotatedFilters(weight.n_rows,
       weight.n_cols, weight.n_slices);
 
   // To perform the backward pass, we need to dilate all the mappedError.
-  arma::Cube<typename MatType::elem_type> dilatedMappedError;
+  CubeType dilatedMappedError;
   if (strideHeight == 1 && strideWidth == 1)
   {
-    MakeAlias(dilatedMappedError, mappedError.memptr(),
-        mappedError.n_rows, mappedError.n_cols, mappedError.n_slices);
+    MakeAlias(dilatedMappedError, mappedError, mappedError.n_rows,
+        mappedError.n_cols, mappedError.n_slices);
   }
   else
   {
     dilatedMappedError.zeros(mappedError.n_rows * strideWidth -
         (strideWidth - 1), mappedError.n_cols * strideHeight -
         (strideHeight - 1), mappedError.n_slices);
-    #pragma omp parallel for collapse(3)
+    #pragma omp parallel for collapse(3) schedule(static)
     for (size_t i = 0; i < mappedError.n_slices; ++i)
     {
       for (size_t j = 0; j < mappedError.n_cols; ++j)
@@ -413,26 +415,26 @@ void ConvolutionType<
     }
   }
 
-  #pragma omp parallel for
+  #pragma omp parallel for schedule(static)
   for (size_t map = 0; map < (size_t) (maps * inMaps); ++map)
   {
     Rotate180(weight.slice(map), rotatedFilters.slice(map));
   }
 
   MatType output(apparentWidth * apparentHeight * inMaps * higherInDimensions,
-      batchSize, arma::fill::zeros);
-  arma::Cube<typename MatType::elem_type> outputCube;
-  MakeAlias(outputCube, output.memptr(), apparentWidth, apparentHeight,
+      batchSize);
+  CubeType outputCube;
+  MakeAlias(outputCube, output, apparentWidth, apparentHeight,
       inMaps * higherInDimensions * batchSize);
 
   // See Forward() for the overall iteration strategy.
+  #pragma omp parallel for schedule(dynamic)
   for (size_t offset = 0; offset < (higherInDimensions * batchSize); ++offset)
   {
     const size_t fullInputOffset = offset * inMaps;
     const size_t fullOutputOffset = offset * maps;
 
     // Iterate over input maps.
-    #pragma omp parallel for
     for (size_t inMap = 0; inMap < (size_t) inMaps; ++inMap)
     {
       // Iterate over output maps.
@@ -453,8 +455,8 @@ void ConvolutionType<
   }
   MatType temp(padding.OutputDimensions()[0] * padding.OutputDimensions()[1] *
       inMaps * higherInDimensions, batchSize);
-  arma::Cube<typename MatType::elem_type> tempCube;
-  MakeAlias(tempCube, temp.memptr(), padding.OutputDimensions()[0],
+  CubeType tempCube;
+  MakeAlias(tempCube, temp, padding.OutputDimensions()[0],
       padding.OutputDimensions()[1], inMaps * higherInDimensions * batchSize);
   paddingBackward.Forward(output, temp);
   if (usingPadding)
@@ -487,10 +489,9 @@ void ConvolutionType<
     const MatType& error,
     MatType& gradient)
 {
-  arma::Cube<typename MatType::elem_type> mappedError;
-  MakeAlias(mappedError, ((MatType&) error).memptr(),
-      this->outputDimensions[0], this->outputDimensions[1],
-      higherInDimensions * maps * batchSize);
+  CubeType mappedError;
+  MakeAlias(mappedError, error, this->outputDimensions[0],
+      this->outputDimensions[1], higherInDimensions * maps * batchSize);
 
   // We are depending here on `inputPadded` being properly set from a call to
   // Forward().
@@ -499,22 +500,23 @@ void ConvolutionType<
   const size_t paddedRows = this->inputDimensions[0] + padWLeft + padWRight;
   const size_t paddedCols = this->inputDimensions[1] + padHTop + padHBottom;
 
-  arma::Cube<typename MatType::elem_type> inputTemp(
+  CubeType inputTemp(
       const_cast<MatType&>(usingPadding ? inputPadded : input).memptr(),
       paddedRows, paddedCols, inMaps * batchSize, false, false);
 
   MatType temp(apparentWidth * apparentHeight * inMaps * higherInDimensions,
       batchSize);
-  arma::Cube<typename MatType::elem_type> tempCube;
-  MakeAlias(tempCube, temp.memptr(), apparentWidth, apparentHeight,
+  CubeType tempCube;
+  MakeAlias(tempCube, temp, apparentWidth, apparentHeight,
       inMaps * higherInDimensions * batchSize);
-  paddingBackward.Backward(input, usingPadding ? inputPadded : input, temp);
+  paddingBackward.Backward(input, {} /* unused */,
+      usingPadding ? inputPadded : input, temp);
 
   // We will make an alias for the gradient, but note that this is only for the
   // convolution map weights!  The bias will be handled by direct accesses into
   // `gradient`.
   gradient.zeros();
-  MakeAlias(gradientTemp, gradient.memptr(), weight.n_rows, weight.n_cols,
+  MakeAlias(gradientTemp, gradient, weight.n_rows, weight.n_cols,
       weight.n_slices);
 
   // See Forward() for our iteration strategy.
@@ -541,7 +543,7 @@ void ConvolutionType<
       }
 
       if (useBias)
-        gradient[weight.n_elem + outMap] += arma::accu(curError);
+        gradient[weight.n_elem + outMap] += accu(curError);
     }
   }
 }
@@ -573,7 +575,7 @@ void ConvolutionType<
     InitializeSamePadding();
   }
 
-  padding = Padding(padWLeft, padWRight, padHTop, padHBottom);
+  padding = PaddingType<MatType>(padWLeft, padWRight, padHTop, padHBottom);
   padding.InputDimensions() = this->inputDimensions;
   padding.ComputeOutputDimensions();
 
@@ -600,7 +602,7 @@ void ConvolutionType<
   apparentHeight = (this->outputDimensions[1] - 1) * strideHeight +
       kernelHeight;
 
-  paddingBackward = Padding(0, padding.OutputDimensions()[0] -
+  paddingBackward = PaddingType<MatType>(0, padding.OutputDimensions()[0] -
       apparentWidth, 0, padding.OutputDimensions()[1] - apparentHeight);
   paddingBackward.InputDimensions() = std::vector<size_t>({ apparentWidth,
       apparentHeight, inMaps * higherInDimensions });
