@@ -87,7 +87,7 @@ class LSTMType : public RecurrentLayer<MatType>
    * Reset the layer parameter. The method is called to
    * assign the allocated memory to the internal learnable parameters.
    */
-  void SetWeights(typename MatType::elem_type* weightsPtr);
+  void SetWeights(const MatType& weightsIn);
 
   /**
    * Ordinary feed-forward pass of a neural network, evaluating the function
@@ -273,7 +273,7 @@ class LSTMType : public RecurrentLayer<MatType>
 // Convenience typedefs.
 
 // Standard LSTM layer.
-typedef LSTMType<arma::mat> LSTM;
+using LSTM = LSTMType<arma::mat>;
 
 } // namespace mlpack
 
