@@ -1,5 +1,5 @@
 /**
- * @file random_forest.hpp
+ * @file methods/random_forest/random_forest.hpp
  * @author Ryan Curtin
  *
  * Definition of the RandomForest class.
@@ -13,29 +13,44 @@
 #define MLPACK_METHODS_RANDOM_FOREST_RANDOM_FOREST_HPP
 
 #include <mlpack/methods/decision_tree/decision_tree.hpp>
-#include <mlpack/methods/decision_tree/multiple_random_dimension_select.hpp>
 #include "bootstrap.hpp"
 
 namespace mlpack {
-namespace tree {
 
+/**
+ * The RandomForest class provides an implementation of random forests,
+ * described in Breiman's seminal paper:
+ *
+ * @code
+ * @article{breiman2001random,
+ *   title={Random forests},
+ *   author={Breiman, Leo},
+ *   journal={Machine Learning},
+ *   volume={45},
+ *   number={1},
+ *   pages={5--32},
+ *   year={2001},
+ *   publisher={Springer}
+ * }
+ * @endcode
+ */
 template<typename FitnessFunction = GiniGain,
          typename DimensionSelectionType = MultipleRandomDimensionSelect,
          template<typename> class NumericSplitType = BestBinaryNumericSplit,
          template<typename> class CategoricalSplitType = AllCategoricalSplit,
-         typename ElemType = double>
+         bool UseBootstrap = true>
 class RandomForest
 {
  public:
   //! Allow access to the underlying decision tree type.
-  typedef DecisionTree<FitnessFunction, NumericSplitType, CategoricalSplitType,
-      DimensionSelectionType, ElemType> DecisionTreeType;
+  using DecisionTreeType = DecisionTree<FitnessFunction, NumericSplitType,
+      CategoricalSplitType, DimensionSelectionType>;
 
   /**
    * Construct the random forest without any training or specifying the number
    * of trees.  Predict() will throw an exception until Train() is called.
    */
-  RandomForest() { }
+  RandomForest();
 
   /**
    * Create a random forest, training on the given labeled training data with
@@ -167,6 +182,8 @@ class RandomForest
    * @param minimumLeafSize Minimum number of points in each tree's leaf nodes.
    * @param minimumGainSplit Minimum gain for splitting a decision tree node.
    * @param maximumDepth Maximum depth for the tree.
+   * @param warmStart When set to `true`, it adds `numTrees` new trees to the
+   *     existing random forest otherwise a new forest is trained from scratch.
    * @param dimensionSelector Instantiated dimension selection policy.
    * @return The average entropy of all the decision trees trained under forest.
    */
@@ -178,6 +195,7 @@ class RandomForest
                const size_t minimumLeafSize = 1,
                const double minimumGainSplit = 1e-7,
                const size_t maximumDepth = 0,
+               const bool warmStart = false,
                DimensionSelectionType dimensionSelector =
                    DimensionSelectionType());
 
@@ -198,6 +216,8 @@ class RandomForest
    * @param minimumLeafSize Minimum number of points in each tree's leaf nodes.
    * @param minimumGainSplit Minimum gain for splitting a decision tree node.
    * @param maximumDepth Maximum depth for the tree.
+   * @param warmStart When set to `true`, it adds `numTrees` new trees to the
+   *     existing random forest else a new forest is trained from scratch.
    * @param dimensionSelector Instantiated dimension selection policy.
    * @return The average entropy of all the decision trees trained under forest.
    */
@@ -210,6 +230,7 @@ class RandomForest
                const size_t minimumLeafSize = 1,
                const double minimumGainSplit = 1e-7,
                const size_t maximumDepth = 0,
+               const bool warmStart = false,
                DimensionSelectionType dimensionSelector =
                    DimensionSelectionType());
 
@@ -228,6 +249,8 @@ class RandomForest
    * @param minimumLeafSize Minimum number of points in each tree's leaf nodes.
    * @param minimumGainSplit Minimum gain for splitting a decision tree node.
    * @param maximumDepth Maximum depth for the tree.
+   * @param warmStart When set to `true`, it adds `numTrees` new trees to the
+   *     existing random forest else a new forest is trained from scratch.
    * @param dimensionSelector Instantiated dimension selection policy.
    * @return The average entropy of all the decision trees trained under forest.
    */
@@ -240,6 +263,7 @@ class RandomForest
                const size_t minimumLeafSize = 1,
                const double minimumGainSplit = 1e-7,
                const size_t maximumDepth = 0,
+               const bool warmStart = false,
                DimensionSelectionType dimensionSelector =
                    DimensionSelectionType());
 
@@ -260,6 +284,8 @@ class RandomForest
    * @param minimumLeafSize Minimum number of points in each tree's leaf nodes.
    * @param minimumGainSplit Minimum gain for splitting a decision tree node.
    * @param maximumDepth Maximum depth for the tree.
+   * @param warmStart When set to `true`, it adds `numTrees` new trees to the
+   *     existing random forest else a new forest is trained from scratch.
    * @param dimensionSelector Instantiated dimension selection policy.
    * @return The average entropy of all the decision trees trained under forest.
    */
@@ -273,6 +299,7 @@ class RandomForest
                const size_t minimumLeafSize = 1,
                const double minimumGainSplit = 1e-7,
                const size_t maximumDepth = 0,
+               const bool warmStart = false,
                DimensionSelectionType dimensionSelector =
                    DimensionSelectionType());
 
@@ -336,7 +363,7 @@ class RandomForest
    * Serialize the random forest.
    */
   template<typename Archive>
-  void serialize(Archive& ar, const unsigned int /* version */);
+  void serialize(Archive& ar, const uint32_t /* version */);
 
  private:
   /**
@@ -354,6 +381,8 @@ class RandomForest
    * @param minimumGainSplit Minimum gain for splitting a decision tree node.
    * @param maximumDepth Maximum depth for the tree.
    * @param dimensionSelector Instantiated dimension selection policy.
+   * @param warmStart When set to `true`, it fits new trees and add them to the
+   *     previous forest else a new forest is trained from scratch.
    * @tparam UseWeights Whether or not to use the weights parameter.
    * @tparam UseDatasetInfo Whether or not to use the datasetInfo parameter.
    * @tparam MatType The type of data matrix (i.e. arma::mat).
@@ -369,13 +398,48 @@ class RandomForest
                const size_t minimumLeafSize,
                const double minimumGainSplit,
                const size_t maximumDepth,
-               DimensionSelectionType& dimensionSelector);
+               DimensionSelectionType& dimensionSelector,
+               const bool warmStart = false);
 
   //! The trees in the forest.
   std::vector<DecisionTreeType> trees;
+
+  //! The average gain of the forest.
+  double avgGain;
 };
 
-} // namespace tree
+/**
+ * Convenience typedef for Extra Trees. (Extremely Randomized Trees Forest)
+ *
+ * @code
+ * @article{10.1007/s10994-006-6226-1,
+ *   author = {Geurts, Pierre and Ernst, Damien and Wehenkel, Louis},
+ *   title = {Extremely Randomized Trees},
+ *   year = {2006},
+ *   issue_date = {April 2006},
+ *   publisher = {Kluwer Academic Publishers},
+ *   address = {USA},
+ *   volume = {63},
+ *   number = {1},
+ *   issn = {0885-6125},
+ *   url = {https://doi.org/10.1007/s10994-006-6226-1},
+ *   doi = {10.1007/s10994-006-6226-1},
+ *   journal = {Mach. Learn.},
+ *   month = apr,
+ *   pages = {3–42},
+ *   numpages = {40},
+ * }
+ * @endcode
+ */
+template<typename FitnessFunction = GiniGain,
+         typename DimensionSelectionType = MultipleRandomDimensionSelect,
+         template<typename> class CategoricalSplitType = AllCategoricalSplit>
+using ExtraTrees = RandomForest<FitnessFunction,
+                                DimensionSelectionType,
+                                RandomBinaryNumericSplit,
+                                CategoricalSplitType,
+                                false>;
+
 } // namespace mlpack
 
 // Include implementation.
