@@ -3,7 +3,7 @@
  * @author Shashank Shekhar
  *
  * This file is an implementation of Pendulum task:
- * https://gym.openai.com/envs/Pendulum-v0/
+ * https://www.gymlibrary.ml/environments/classic_control/pendulum/
  *
  * TODO: provide an option to use dynamics directly from OpenAI gym.
  *
@@ -17,10 +17,8 @@
 #define MLPACK_METHODS_RL_ENVIRONMENT_PENDULUM_HPP
 
 #include <mlpack/prereqs.hpp>
-#include <mlpack/core/math/clamp.hpp>
 
 namespace mlpack {
-namespace rl {
 
 /**
  * Implementation of Pendulum task. The inverted pendulum swingup problem is a
@@ -41,7 +39,7 @@ class Pendulum
     /**
      * Construct a state instance.
      */
-    State() : theta(0), data(dimension, arma::fill::zeros)
+    State() : theta(0), data(dimension)
     { /* Nothing to do here. */ }
 
     /**
@@ -154,7 +152,7 @@ class Pendulum
     const double length = 1.0;
 
     // Get action and clip the values between max and min limits.
-    double torque = math::ClampRange(action.action[0], -maxTorque, maxTorque);
+    double torque = std::min(std::max(action.action[0], -maxTorque), maxTorque);
 
     // Calculate costs of taking this action in the current state.
     double costs = std::pow(AngleNormalize(theta), 2) + 0.1 *
@@ -165,8 +163,8 @@ class Pendulum
         length) * std::sin(theta + M_PI) + 3.0 / (mass * std::pow(length, 2)) *
         torque) * dt;
     nextState.Theta() = theta + newAngularVelocity * dt;
-    nextState.AngularVelocity() = math::ClampRange(newAngularVelocity,
-        -maxAngularVelocity, maxAngularVelocity);
+    nextState.AngularVelocity() = std::min(std::max(newAngularVelocity,
+        -maxAngularVelocity), maxAngularVelocity);
 
     nextState.SetState();
 
@@ -197,8 +195,8 @@ class Pendulum
   State InitialSample()
   {
     State state;
-    state.Theta() = math::Random(-M_PI, M_PI);
-    state.AngularVelocity() = math::Random(-1.0, 1.0);
+    state.Theta() = Random(-M_PI, M_PI);
+    state.AngularVelocity() = Random(-1.0, 1.0);
     stepsPerformed = 0;
     state.SetState();
     return state;
@@ -263,7 +261,6 @@ class Pendulum
   size_t stepsPerformed;
 };
 
-} // namespace rl
 } // namespace mlpack
 
 #endif
