@@ -13,10 +13,10 @@
 #ifndef MLPACK_METHODS_RL_WORKER_ONE_STEP_Q_LEARNING_WORKER_HPP
 #define MLPACK_METHODS_RL_WORKER_ONE_STEP_Q_LEARNING_WORKER_HPP
 
+#include <ensmallen.hpp>
 #include <mlpack/methods/reinforcement_learning/training_config.hpp>
 
 namespace mlpack {
-namespace rl {
 
 /**
  * One step Q-Learning worker.
@@ -282,7 +282,7 @@ class OneStepQLearningWorker
     {
       // Initialize the gradient storage.
       arma::mat totalGradients(learningNetwork.Parameters().n_rows,
-          learningNetwork.Parameters().n_cols, arma::fill::zeros);
+          learningNetwork.Parameters().n_cols);
       for (size_t i = 0; i < pending.size(); ++i)
       {
         TransitionType &transition = pending[i];
@@ -399,7 +399,6 @@ class OneStepQLearningWorker
   StateType state;
 };
 
-} // namespace rl
 } // namespace mlpack
 
 #endif
