@@ -31,14 +31,14 @@ TEST_CASE("PReLUFORWARDTest", "[ANNLayerTest]")
   PReLU module(0.01);
   arma::mat moduleParams(module.WeightSize(), 1);
   module.CustomInitialize(moduleParams, module.WeightSize());
-  module.SetWeights((double*) moduleParams.memptr());
+  module.SetWeights(moduleParams);
   arma::mat predOutput;
   module.Forward(input, predOutput);
   arma::mat actualOutput = {{0.5, 1.2, 3.1},
                            {-0.022, -0.015, 0.8},
                            {5.5, -0.047, 2.1},
                            {0.2, 0.1, -0.005}};
-  REQUIRE(arma::accu(arma::abs(actualOutput - predOutput)) ==
+  REQUIRE(accu(arma::abs(actualOutput - predOutput)) ==
       Approx(0.0).margin(1e-4));
 }
 
@@ -54,7 +54,7 @@ TEST_CASE("PReLUBACKWARDTest", "[ANNLayerTest]")
   PReLU module(0.01);
   arma::mat moduleParams(module.WeightSize(), 1);
   module.CustomInitialize(moduleParams, module.WeightSize());
-  module.SetWeights((double*) moduleParams.memptr());
+  module.SetWeights(moduleParams);
   arma::mat gy = {{0.2, -0.5, 0.8},
                  {1.5, -0.6, 0.1},
                  {-0.3, 0.2, -0.5},
@@ -68,7 +68,7 @@ TEST_CASE("PReLUBACKWARDTest", "[ANNLayerTest]")
                       {-0.3, 0.002, -0.5},
                       {0.1, -0.1, 0.0030}};
 
-  REQUIRE(arma::accu(arma::abs(actualG - predG)) ==
+  REQUIRE(accu(arma::abs(actualG - predG)) ==
       Approx(0.0).margin(1e-4));
 }
 
@@ -84,7 +84,7 @@ TEST_CASE("PReLUGRADIENTTest", "[ANNLayerTest]")
   PReLU module(0.01);
   arma::mat moduleParams(module.WeightSize(), 1);
   module.CustomInitialize(moduleParams, module.WeightSize());
-  module.SetWeights((double*) moduleParams.memptr());
+  module.SetWeights(moduleParams);
   arma::mat error = {{0.2, -0.5,  0.8},
                     {-0.015, -0.006, 0.001},
                     {-0.3,  0.002, -0.005},
@@ -92,13 +92,13 @@ TEST_CASE("PReLUGRADIENTTest", "[ANNLayerTest]")
   arma::mat predGradient;
   module.Gradient(input, error, predGradient);
 
-  REQUIRE(0.0103 - arma::accu(predGradient) ==
+  REQUIRE(0.0103 - accu(predGradient) ==
       Approx(0.0).margin(1e-4));
 }
 
 double ComputeMSRE(arma::mat input, arma::mat target)
 {
-  return std::pow(arma::accu(arma::pow(input - target, 2)) / target.n_cols, 0.5);
+  return std::pow(accu(pow(input - target, 2)) / target.n_cols, 0.5);
 }
 
 TEST_CASE("PReLUIntegrationTest", "[ANNLayerTest]")
@@ -132,8 +132,6 @@ TEST_CASE("PReLUIntegrationTest", "[ANNLayerTest]")
     double msreTrain = ComputeMSRE(predictions, trainLabels);
     model.Predict(testData, predictions);
     double msreTest = ComputeMSRE(predictions, testLabels);
-    std::cout << "train: " << msreTrain << "\n";
-    std::cout << "test: " << msreTest << "\n";
 
     double relativeMSRE = std::abs((msreTest - msreTrain) / msreTrain);
     if (relativeMSRE <= 0.35)
