@@ -92,8 +92,8 @@ TEST_CASE("PoissonNLLLossTest", "[LossFunctionsTest]")
   target = arma::mat("1.0 3.0 1.0 2.0 1.0 4.0 2.0 1.0");
 
   // Input required for module 4. Probs are in range [0, 1].
-  input4 = arma::mat("0.658502 0.445627 0.667651 0.310549 \
-                      0.589540 0.052568 0.549769 0.381504 ");
+  input4 = arma::mat("0.658502 0.445627 0.667651 0.310549 "
+                     "0.589540 0.052568 0.549769 0.381504 ");
   target4 = arma::mat("1.0 3.0 1.0 2.0 1.0 4.0 2.0 1.0");
 
   double loss1 = module1.Forward(input, target);
@@ -111,14 +111,14 @@ TEST_CASE("PoissonNLLLossTest", "[LossFunctionsTest]")
   module3.Backward(input, target, output3);
   module4.Backward(input4, target4, output4);
 
-  expOutput1 = arma::mat("0.214785 -0.0352148 0.710737 0.369129 \
-                         -0.106304 4.55591 -0.204015 0.0810902");
-  expOutput2 = arma::mat("1.71828 -0.281718 5.68589 2.95303\
-                         -0.850431 36.4473 -1.63212 0.648721");
-  expOutput3 = arma::mat("0.214785 -0.035215 0.710737 0.369129 \
-                         -0.106304 4.555913 -0.204015 0.081090");
-  expOutput4 = arma::mat("-0.064825 -0.716511 -0.062224 -0.680027 \
-                          -0.087030 -9.386517 -0.329736 -0.202650");
+  expOutput1 = arma::mat("0.214785 -0.0352148 0.710737 0.369129 "
+                         "-0.106304 4.55591 -0.204015 0.0810902");
+  expOutput2 = arma::mat("1.71828 -0.281718 5.68589 2.95303 "
+                         "-0.850431 36.4473 -1.63212 0.648721");
+  expOutput3 = arma::mat("0.214785 -0.035215 0.710737 0.369129 "
+                         "-0.106304 4.555913 -0.204015 0.081090");
+  expOutput4 = arma::mat("-0.064825 -0.716511 -0.062224 -0.680027 "
+                         "-0.087030 -9.386517 -0.329736 -0.202650");
 
   REQUIRE(output1.n_rows == input.n_rows);
   REQUIRE(output1.n_cols == input.n_cols);
@@ -437,8 +437,8 @@ TEST_CASE("SimpleEarthMoverDistanceLayerTest", "[LossFunctionsTest]")
   REQUIRE(output.n_rows == input2.n_rows);
   REQUIRE(output.n_cols == input2.n_cols);
 
-   // Test for mean reduction.
-   module.Reduction() = false;
+  // Test for mean reduction.
+  module.Reduction() = false;
   input3 = arma::mat("-0.0494 -1.1958 -1.0486 -0.2121 1.6028 0.0737 -0.7091 "
       "0.8612 0.9639 0.9648 0.0745 0.5924");
   target3 = arma::mat("0.4316 0.0164 -0.4478 1.1452 0.5106 0.9255 0.5571 "
@@ -611,7 +611,7 @@ TEST_CASE("SimpleMeanBiasErrorTest", "[LossFunctionsTest]")
   // Test the backward function.
   module.Backward(input, target, output);
 
-  for(double el : output)
+  for (double el : output)
     REQUIRE(el == -1);
   REQUIRE(output.n_rows == input.n_rows);
   REQUIRE(output.n_cols == input.n_cols);
@@ -628,7 +628,7 @@ TEST_CASE("SimpleMeanBiasErrorTest", "[LossFunctionsTest]")
   // Test the backward function
   module.Backward(input, target, output);
 
-  for(double el : output)
+  for (double el : output)
     REQUIRE(el == Approx(-0.0833).epsilon(1e-3));
   REQUIRE(accu(output) == Approx(-1).epsilon(1e-5));
   REQUIRE(output.n_rows == input.n_rows);
@@ -828,14 +828,14 @@ TEST_CASE("MarginRankingLossTest", "[LossFunctionsTest]")
       "-4.8090 4.3455 5.2070");
   input2 = arma::mat("-4.5288 -9.2766 -0.5882 -5.6643 -6.0175 8.8506 3.4759 "
       "-9.4886 2.2755 8.4951");
-  expectedOutput = { { 0.0, 0.0,  1.0, 0.0,  1.0, -1.0, 0.0, 0.0,  1.0, -1.0 }, 
-                     { 0.0, 0.0, -1.0, 0.0, -1.0,  1.0, 0.0, 0.0, -1.0,  1.0 } };
+  expectedOutput = {{ 0.0, 0.0,  1.0, 0.0,  1.0, -1.0, 0.0, 0.0,  1.0, -1.0 },
+                    { 0.0, 0.0, -1.0, 0.0, -1.0,  1.0, 0.0, 0.0, -1.0,  1.0 }};
   input = join_cols(input1, input2);
   target = arma::mat("1 1 -1 1 -1 1 1 1 -1 1");
 
-  // Test the forward function
-  // loss should be 30.3530 
-  // value calculated using torch.nn.MarginRankingLoss(margin=1.0,reduction='sum')
+  // Test the forward function; loss should be 30.3530.
+  // Value calculated using:
+  //     torch.nn.MarginRankingLoss(margin=1.0,reduction='sum')
   loss = module.Forward(input, target);
   REQUIRE(loss == Approx(30.3530).epsilon(1e-3));
 
@@ -848,16 +848,16 @@ TEST_CASE("MarginRankingLossTest", "[LossFunctionsTest]")
   // Test for mean reduction by modifying reduction parameter using accessor.
   module.Reduction() = false;
 
-  // Test the forward function
-  // loss should be 3.0353
-  // value calculated using torch.nn.MarginRankingLoss(margin=1.0,reduction='mean')
+  // Test the forward function; loss should be 3.0353.
+  // Value calculated using:
+  //     torch.nn.MarginRankingLoss(margin=1.0,reduction='mean')
   loss = module.Forward(input, target);
   REQUIRE(loss == Approx(3.0353).epsilon(1e-5));
 
-  // Test the backward function
+  // Test the backward function.
   module.Backward(input, target, output);
-  expectedOutput = { { 0.0, 0.0,  0.1, 0.0,  0.1, -0.1, 0.0, 0.0,  0.1, -0.1 },
-                     { 0.0, 0.0, -0.1, 0.0, -0.1,  0.1, 0.0, 0.0, -0.1,  0.1 } };
+  expectedOutput = {{ 0.0, 0.0,  0.1, 0.0,  0.1, -0.1, 0.0, 0.0,  0.1, -0.1 },
+                    { 0.0, 0.0, -0.1, 0.0, -0.1,  0.1, 0.0, 0.0, -0.1,  0.1 }};
   REQUIRE(output.n_rows == input.n_rows);
   REQUIRE(output.n_cols == input.n_cols);
   CheckMatrices(output, expectedOutput, 0.1);
